==> RQuantLib_0.3.3.tar.gz: RQuantLib/R/hullWhiteCalibration.R <==
## RQuantLib -- R interface to the QuantLib libraries
##
## Copyright (C) 2010        Dirk Eddelbuettel and Khanh Nguyen
##
## $Id: hullWhiteCalibration.R 259 2010-06-18 01:00:08Z edd $
##
## This file is part of the RQuantLib library for GNU R.
## It is made available under the terms of the GNU General Public
## License, version 2, or at your option, any later version,
## incorporated herein by reference.
##
## This program is distributed in the hope that it will be
## useful, but WITHOUT ANY WARRANTY; without even the implied
## warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more
## details.
##
## You should have received a copy of the GNU General Public
## License along with this program; if not, write to the Free
## Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
## MA 02111-1307, USA

hullWhiteCalibrateUsingCap <- function(termStrc, capHelpers,
                                       index, evaluationDate) {
  capData <- capHelpers$data

  indexparams <- list(type=index$type);
  ibor <- index$term

  val <- .Call("QL_HullWhiteCalibrationUsingCap",
               termStrc$table$date,
               termStrc$table$zeroRates,
               capData,
               ibor$table$date,
               ibor$table$zeroRates,
               indexparams,
               evaluationDate)
}

hullWhiteCalibrateUsingSwap <- function(termStrc, swapHelpers,
                               index, evaluationDate){
  swapData <- swapHelpers$data

  indexparams <- list(type=index$type);
  ibor <- index$term

  val <- .Call("QL_HullWhiteCalibrationUsingSwap",
               termStrc$table$date,
               termStrc$table$zeroRates,
               swapData,
               ibor$table$date,
               ibor$table$zeroRates,
               indexparams,
               evaluationDate)
}

==> RQuantLib_0.3.4.tar.gz: RQuantLib/R/hullWhiteCalibration.R <==
## RQuantLib -- R interface to the QuantLib libraries
##
## Copyright (C) 2010        Dirk Eddelbuettel and Khanh Nguyen
##
## $Id: hullWhiteCalibration.R 293 2010-08-07 15:56:13Z edd $
##
## This file is part of the RQuantLib library for GNU R.
## It is made available under the terms of the GNU General Public
## License, version 2, or at your option, any later version,
## incorporated herein by reference.
##
## This program is distributed in the hope that it will be
## useful, but WITHOUT ANY WARRANTY; without even the implied
## warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more
## details.
##
## You should have received a copy of the GNU General Public
## License along with this program; if not, write to the Free
## Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
## MA 02111-1307, USA

hullWhiteCalibrateUsingCap <- function(termStrc, capHelpers,
                                       index, evaluationDate) {
  capData <- capHelpers$data

  indexparams <- list(type=index$type);
  ibor <- index$term

  val <- .Call("HullWhiteCalibrationUsingCap",
               termStrc$table$date,
               termStrc$table$zeroRates,
               capData,
               ibor$table$date,
               ibor$table$zeroRates,
               indexparams,
               evaluationDate)
}

hullWhiteCalibrateUsingSwap <- function(termStrc, swapHelpers,
                               index, evaluationDate){
  swapData <- swapHelpers$data

  indexparams <- list(type=index$type);
  ibor <- index$term

  val <- .Call("HullWhiteCalibrationUsingSwap",
               termStrc$table$date,
               termStrc$table$zeroRates,
               swapData,
               ibor$table$date,
               ibor$table$zeroRates,
               indexparams,
               evaluationDate)
}
